
CREATE SCHEMA documentdb_api_distributed;
GRANT USAGE ON SCHEMA documentdb_api_distributed TO documentdb_admin_role;
GRANT USAGE ON SCHEMA documentdb_api_distributed TO documentdb_readonly_role;
CREATE TABLE documentdb_api_distributed.documentdb_cluster_data
(
    metadata documentdb_core.bson
);
-- seed the table with a baseline version.
INSERT INTO documentdb_api_distributed.documentdb_cluster_data (metadata) VALUES ( '{ "last_deploy_version": "0.0-0" }'::documentdb_core.bson );
CREATE OR REPLACE FUNCTION documentdb_api_distributed.initialize_cluster()
RETURNS void
 SET search_path TO documentdb_api_catalog, pg_catalog
 SET citus.enable_ddl_propagation TO on
 SET citus.enable_unsafe_triggers TO on
 SET citus.multi_shard_modify_mode TO 'sequential'
LANGUAGE c
 STRICT
AS 'MODULE_PATHNAME', $function$command_initialize_cluster$function$;
CREATE OR REPLACE FUNCTION documentdb_api_distributed.complete_upgrade()
RETURNS bool
    SET citus.enable_unsafe_triggers TO on
    SET citus.enable_ddl_propagation TO on
    SET citus.multi_shard_modify_mode TO 'sequential'
LANGUAGE c
STRICT
AS 'MODULE_PATHNAME', $function$command_complete_upgrade$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.invalidate_cached_cluster_versions()
RETURNS void
LANGUAGE C
IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$invalidate_cluster_version$function$;
CREATE OR REPLACE FUNCTION documentdb_api_internal.get_current_cached_cluster_version()
RETURNS text
LANGUAGE C
IMMUTABLE PARALLEL SAFE STRICT
AS 'MODULE_PATHNAME', $function$get_current_cached_cluster_version$function$;
CREATE FUNCTION documentdb_api_internal.update_documentdb_version_data()
 RETURNS trigger
 LANGUAGE plpgsql
AS $function$
BEGIN
 RAISE NOTICE 'Invalidating cached cluster version data';
 PERFORM documentdb_api_internal.invalidate_cached_cluster_versions();
 RETURN NULL;
END;
$function$;
ALTER TABLE documentdb_api_distributed.documentdb_cluster_data ADD PRIMARY KEY (metadata);
CREATE OR REPLACE FUNCTION documentdb_api_distributed.rebalancer_status(p_spec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE C
   STRICT
 AS 'MODULE_PATHNAME', $$command_rebalancer_status$$;
CREATE OR REPLACE FUNCTION documentdb_api_distributed.rebalancer_start(p_spec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE C
   STRICT
 AS 'MODULE_PATHNAME', $$command_rebalancer_start$$;
CREATE OR REPLACE FUNCTION documentdb_api_distributed.rebalancer_stop(p_spec documentdb_core.bson)
 RETURNS documentdb_core.bson
 LANGUAGE C
   STRICT
 AS 'MODULE_PATHNAME', $$command_rebalancer_stop$$;
